@@ -7,6 +7,7 @@ use base qw( XML::Atom::Base );
 use XML::Atom;
 use base qw( XML::Atom::ErrorHandler );
 use XML::Atom::Util qw( first nodelist childlist remove_default_ns create_element );
+use XML::Atom::Category;
 use XML::Atom::Link;
 use LWP::UserAgent;
 BEGIN {
@@ -87,35 +88,16 @@ sub set {
     }
 }
 
-sub add_link {
-    my $thing = shift;
-    my($link) = @_;
-    my $elem = ref $link eq 'XML::Atom::Link' ?
-            $link->elem :
-            create_element($thing->ns, 'link');
-    $thing->elem->appendChild($elem);
-    if (ref($link) eq 'HASH') {
-        for my $k (qw( type rel href title )) {
-            my $v = $link->{$k} or next;
-            $elem->setAttribute($k, $v);
-        }
-    }
-}
+# common elements
+__PACKAGE__->mk_elem_accessors(qw( icon id logo title )); # updated & rights are in renamed
 
-sub link {
-    my $thing = shift;
-    if (wantarray) {
-        my @res = childlist($thing->elem, $thing->ns, 'link');
-        my @links;
-        for my $elem (@res) {
-            push @links, XML::Atom::Link->new(Elem => $elem);
-        }
-        return @links;
-    } else {
-        my $elem = first($thing->elem, $thing->ns, 'link') or return;
-        return XML::Atom::Link->new(Elem => $elem);
-    }
-}
+# common multiple elements
+__PACKAGE__->mk_object_list_accessor('link' => 'XML::Atom::Link', 'links');
+__PACKAGE__->mk_object_list_accessor('category' => 'XML::Atom::Category', 'categories');
+__PACKAGE__->mk_object_list_accessor('author' => 'XML::Atom::Person', 'authors');
+__PACKAGE__->mk_object_list_accessor('contributor' => 'XML::Atom::Person', 'contributors');
+
+__PACKAGE__->_rename_elements('copyright' => 'rights');
 
 # 0.3 -> 1.0 elements aliasing
 sub _rename_elements {
@@ -138,16 +120,4 @@ sub _rename_elements {
     };
 }
 
-sub DESTROY { }
-
-use vars qw( $AUTOLOAD );
-sub AUTOLOAD {
-    (my $var = $AUTOLOAD) =~ s!.+::!!;
-    no strict 'refs';
-    *$AUTOLOAD = sub {
-        @_ > 1 ? $_[0]->set($_[0]->ns, $var, @_[1..$#_]) : $_[0]->get($_[0]->ns, $var)
-    };
-    goto &$AUTOLOAD;
-}
-
 1;
